(*******************************************************************

  CarbonSoft cxCPU2000 VCL Extension v3.0
  VCL Demo Main Form

  Copyright  2000 CarbonSoft. All rights reserved.

  About this Demo:
  This demo demonstrates the simplest method of using cxCpu2000. The
  cxCpu2000 component's AutoBench property has been enabled causing
  it to perform the processor benchmark when it is created. The rest
  of the code simply reads and displays the various properties.

  Important cxCpu2000 Information:
  You (individual or organisation) are free to use this library and
  associated component in compiled form for any purpose but you may
  NOT create derivative products, including (but not limited to) DLL,
  COM, or ActiveX implementations for any platform for distribution
  without written permission from CarbonSoft.

  The source code may NOT be redistributed, in whole or in part, for
  profit or otherwise without written permission from CarbonSoft.

  If you have any queries please contact: licensing@carbonsoft.com

 *******************************************************************)
unit dMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, cxCPU2kVcl, ComCtrls, ShellAPI {$IFDEF VER110},ImgList{$ENDIF};

type
  TForm1 = class(TForm)
    PageControl1: TPageControl;
    tabIdentification: TTabSheet;
    tabFeatureSet: TTabSheet;
    tabAboutcxCpu2000: TTabSheet;
    cxCpu: TcxCPU2000;
    imlSupport: TImageList;
    Label2: TLabel;
    Label12: TLabel;
    Label14: TLabel;
    Label4: TLabel;
    Label16: TLabel;
    lblVclVersion: TLabel;
    lblApiVersion: TLabel;
    Label20: TLabel;
    Panel3: TPanel;
    Panel5: TPanel;
    Panel4: TPanel;
    FeatureList: TListView;
    lblName: TLabel;
    Label1: TLabel;
    Label3: TLabel;
    lblSpeed: TLabel;
    Label5: TLabel;
    lblSerial: TLabel;
    Label6: TLabel;
    lblFDiv: TLabel;
    Label8: TLabel;
    lblMMX: TLabel;
    lblType: TLabel;
    Label11: TLabel;
    lbl3DNow: TLabel;
    lblSIMD: TLabel;
    Label7: TLabel;
    lblL1Data: TLabel;
    lblL1Code: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    lblLevel1: TLabel;
    lblLevel2: TLabel;
    Label13: TLabel;
    Label15: TLabel;
    lblVendor: TLabel;
    Panel1: TPanel;
    Panel2: TPanel;
    Button2: TButton;
    procedure FormCreate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Label7Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormCreate(Sender: TObject);
  procedure AddFeature(AFeature: String; ADescription: String; APresent: Boolean);
  var
    lviFeature: TListItem;
  begin
    lviFeature := FeatureList.Items.Add;
    lviFeature.Caption := AFeature;
    lviFeature.SubItems.Add(ADescription);
    lviFeature.ImageIndex := integer(not(APresent));
  end;
begin
  PageControl1.ActivePage := TabIdentification;
  if (Screen.Fonts.IndexOf('Tahoma') <> (-1)) then
    Font.Name:= 'Tahoma';
  Panel1.Font.Name:= Font.Name;
  Panel2.Font.Name:= Font.Name;
  Panel3.Font.Name:= Font.Name;
  Panel4.Font.Name:= Font.Name;
  Panel5.Font.Name:= Font.Name;

  // Processor details
  lblName.Caption:= cxCpu.FullName;
  lblVendor.Caption:= cxCpu.Vendor;
  lblSpeed.Caption:= IntToStr(cxCpu.Speed) + ' Mhz';
  lblSerial.Caption:= cxCpu.Serial;
  if (cxCpu.FDivBug) then
    lblFDiv.Caption:= 'Present'
  else
    lblFDiv.Caption:= 'Not Present';
  if (cxCpu.OverDrive) then
    lblType.Caption:= 'OverDrive Processor'
  else
    lblType.Caption:= 'OEM or Retail Processor';

  if (cxCpu.MMX) then
    lblMMX.Caption:= 'MMX Instructions Supported'
  else
    lblMMX.Caption:= 'MMX Instructions not supported';

  if (cxCpu.FeatureSet.SIMD) then
    lblSIMD.Caption:= 'SIMD Instructions Supported'
  else
    lblSIMD.Caption:= 'SIMD Instructions not supported';

  if (cxCpu.FeatureSetEx.AMD3DNow) then
    lbl3DNow.Caption:= '3DNow! Instructions Supported'
  else
    lbl3DNow.Caption:= '3DNow! Instructions not supported';

  lblL1Code.Caption:= IntToStr(cxCpu.Cache.L1Code) + ' Kb';
  lblL1Data.Caption:= IntToStr(cxCpu.Cache.L1Data) + ' Kb';
  lblLevel1.Caption:= IntToStr(cxCpu.Cache.Level1) + ' Kb';
  lblLevel2.Caption:= IntToStr(cxCpu.Cache.Level2) + ' Kb';

  // Feature Set
  FeatureList.Items.BeginUpdate;
  AddFeature('FPU', 'Floating Point Processor', cxCpu.FeatureSet.FPU);
  AddFeature('VME', 'Virtual Mode Extension', cxCpu.FeatureSet.VME);
  AddFeature('DE', 'Debugging Extension', cxCpu.FeatureSet.DE);
  AddFeature('PSE', 'Page Size Extension', cxCpu.FeatureSet.PSE);
  AddFeature('TSC', 'Time Stamp Counter', cxCpu.FeatureSet.TSC);
  AddFeature('MSR', 'Model Specific Registers', cxCpu.FeatureSet.MSR);
  AddFeature('PAE', 'Physical Address Extension', cxCpu.FeatureSet.PAE);
  AddFeature('MCE', 'Machine Check Exception', cxCpu.FeatureSet.MCE);
  AddFeature('CX8', 'CMPXCHG8 Instruction', cxCpu.FeatureSet.CX8);
  AddFeature('APIC', 'On-chip APIC Hardware', cxCpu.FeatureSet.APIC);
  AddFeature('SEP', 'Fast System Call', cxCpu.FeatureSet.SEP);
  AddFeature('MTRR', 'Memory Type Range Registers', cxCpu.FeatureSet.MTRR);
  AddFeature('PGE', 'Page Global Enable', cxCpu.FeatureSet.PGE);
  AddFeature('MCA', 'Machine Check Architecture', cxCpu.FeatureSet.MCA);
  AddFeature('CMOV', 'Conditional Move Instruction', cxCpu.FeatureSet.CMOV);
  AddFeature('PAT', 'Page Attribute Table', cxCpu.FeatureSet.PAT);
  AddFeature('PSE36', '36-bit Page Size Extension', cxCpu.FeatureSet.PSE36);
  AddFeature('SERIAL', 'Processor Serial Number', cxCpu.FeatureSet.SERIAL);
  AddFeature('CLFLUSH', 'CLFLUSH Instruction', cxCpu.FeatureSet.CLFLUSH);
  AddFeature('DTS', 'Debug Trace Store', cxCpu.FeatureSet.DTS);
  AddFeature('ACPI', 'Advanced Configuration and Power Management Interface', cxCpu.FeatureSet.ACPI);
  AddFeature('MMX', 'MMX Extensions', cxCpu.FeatureSet.MMX);
  AddFeature('FXSR', 'Floating Point Save and Restore', cxCpu.FeatureSet.XSR);
  AddFeature('SIMD', 'Streaming SIMD Extensions', cxCpu.FeatureSet.SIMD);
  AddFeature('SIMD2', 'Streaming SIMD Extensions 2', cxCpu.FeatureSet.SIMD2);
  AddFeature('SS', 'Self-Snoop', cxCpu.FeatureSet.SS);
  AddFeature('TM', 'Thermal Monitor Supported', cxCpu.FeatureSet.TM);

  AddFeature('3DNOW', '3DNow! Extensions', cxCpu.FeatureSetEx.AMD3DNow);
  AddFeature('3DNOWEX', 'Enhanced 3DNow! Extensions', cxCpu.FeatureSetEx.AMD3DNowEx);
  AddFeature('MMXEX', 'Enhanced MMX Extensions', cxCpu.FeatureSetEx.MMXEx);

  //FeatureList.SortType:= stText;
  FeatureList.Items.EndUpdate;

  // About Information
  lblVclVersion.Caption:= 'CarbonSoft cxCpu Vcl Component version ' +
                           FloatToStr(cxCpu.VersionInfo.VCL.Version) +
                           ' (Build ' + IntToStr(cxCpu.VersionInfo.VCL.Build) + ')';
  lblApiVersion.Caption:= 'CarbonSoft cxCpu Detection API version ' +
                           FloatToStr(cxCpu.VersionInfo.API.Version) +
                           ' (Build ' + IntToStr(cxCpu.VersionInfo.API.Build) + ')';
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  Close;
end;

procedure TForm1.Label7Click(Sender: TObject);
begin
  ShellExecute(Self.Handle, 'open', 'http://www.carbonsoft.com/', '', '', SW_NORMAL);
end;

end.
